
#ifndef _C14_fi664_
#define _C14_fi664_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1249_11954(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit664(void);

#ifdef __cplusplus
}
#endif

#endif
